# Other functions

<br/><br/>
In order to read the model, use the respective utility functions.
In order to save a model, use the respective CytoNorm.save() function (see respective documentation).

```{eval-rst}

.. currentmodule:: cytonormpy

.. autosummary::
    :toctree: ../generated/
    :nosignatures:

    read_model
```

<br/><br/>
Evaluation functions for MAD calculation have been implemented
in the following functions:

```{eval-rst}

.. currentmodule:: cytonormpy

.. autosummary::
    :toctree: ../generated/
    :nosignatures:

    mad_from_fcs
    mad_comparison_from_fcs
    mad_from_anndata
    mad_comparison_from_anndata
```


<br/><br/>
Evaluation functions for EMD calculation have been implemented
in the following functions:

```{eval-rst}

.. currentmodule:: cytonormpy

.. autosummary::
    :toctree: ../generated/
    :nosignatures:


    emd_from_fcs
    emd_comparison_from_fcs
    emd_from_anndata
    emd_comparison_from_anndata

```

